@@ -6,9 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client;
-$BZ::Client::VERSION = '4.4_001'; # TRIAL
+$BZ::Client::VERSION = '4.4001_001'; # TRIAL
 
-$BZ::Client::VERSION = '4.4001';
+$BZ::Client::VERSION = '4.4001001';
 use BZ::Client::XMLRPC;
 use BZ::Client::Exception;
 use HTTP::CookieJar;
@@ -295,7 +295,7 @@ BZ::Client - A client for the Bugzilla web services API.
 
 =head1 VERSION
 
-version 4.4_001
+version 4.4001_001
 
 =head1 SYNOPSIS
 
@@ -540,6 +540,10 @@ This is used internally to set cookies with the log in functions. Don't touch th
 
 =back
 
+=head1 EXCEPTION HANDLING
+
+See L<BZ::Client::Exception>
+
 =head1 ERROR CODES
 
 =head2 300 (Invalid Username or Password)
@@ -584,7 +588,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dean Hamstad.
+This software is copyright (c) 2017 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
