@@ -6,9 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bug;
-$BZ::Client::Bug::VERSION = '4.4_001'; # TRIAL
+$BZ::Client::Bug::VERSION = '4.4001_001'; # TRIAL
 
-$BZ::Client::Bug::VERSION = '4.4001';
+$BZ::Client::Bug::VERSION = '4.4001001';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bug.html
@@ -288,7 +288,7 @@ BZ::Client::Bug - Client side representation of a bug in Bugzilla
 
 =head1 VERSION
 
-version 4.4_001
+version 4.4001_001
 
 =head1 SYNOPSIS
 
@@ -381,6 +381,10 @@ Example:
  BZ::Client::User->get( $client,
     { ids => [1], include_fields => ['_all'] })
 
+=head1 EXCEPTION HANDLING
+
+See L<BZ::Client::Exception>
+
 =head1 UTILITY FUNCTIONS
 
 This section lists the utility functions provided by this module.
@@ -506,9 +510,9 @@ I<sort_key> (int) Values, when displayed in a list, are sorted first by this int
 
 =item sortkey
 
-DEPRECATED - Use L</sort_key> instead.
+B<DEPRECATED> - Use L</sort_key> instead.
 
-Renamed to sort_key in Bugzilla 4.2.
+Renamed to C<sort_key> in Bugzilla 4.2.
 
 =item visibility_values
 
@@ -674,7 +678,7 @@ You do not have access to the bug_id you specified.
 
 =head2 search
 
-FIXME
+FIXME Documentation not fully fleshed out
 
  @bugs = BZ::Client::Bug->search( $client, \%params );
  $bugs = BZ::Client::Bug->search( $client, \%params );
@@ -686,6 +690,7 @@ Searches for bugs matching the given parameters.
 This is just a quick example, there are lot's of fields
 
  %params = (
+
    'alias' => 'ACONVENIENTALIAS',
 
    'assigned_to' => 'hopefullynotme@domain.local',
@@ -745,7 +750,7 @@ I<alias> (array) The alias of this bug. If there is no alias, this will be undef
 
 =item history
 
-An array of hashes, each hash having the following keys:
+I<history> (An array of hashes) - Each hash having the following keys:
 
 =over 4
 
@@ -854,9 +859,157 @@ Listed here in order of what you most likely want to do... maybe?
 
   my $id = BZ::Client::Bug->create( $client, \%params );
 
-Creates a new bug in your Bugzilla server and returns the bug ID.
+This allows you to create a new bug in Bugzilla. If you specify any invalid fields, an error will be thrown stating which field is invalid. If you specify any fields you are not allowed to set, they will just be set to their defaults or ignored.
 
-FIXME more details needed
+You cannot currently set all the items here that you can set on enter_bug.cgi (i.e. the web page to enter bugs).
+
+The Bugzilla WebService API itself may allow you to set things other than those listed here, but realize that anything undocumented is B<UNSTABLE> and will very likely change in the future.
+
+=head3 History
+
+Before Bugzilla 3.0.4, parameters marked as B<Defaulted> were actually B<Required>, due to a bug in Bugzilla itself.
+
+The groups argument was added in Bugzilla B<4.0>. Before Bugzilla 4.0, bugs were only added into Mandatory groups by this method. Since Bugzilla B<4.0.2>, passing an illegal group name will throw an error. In Bugzilla 4.0 and 4.0.1, illegal group names were silently ignored.
+
+The C<comment_is_private> argument was added in Bugzilla B<4.0>. Before Bugzilla 4.0, you had to use the undocumented C<commentprivacy> argument.
+
+Error C<116> was added in Bugzilla B<4.0>. Before that, dependency loop errors had a generic code of C<32000>.
+
+The ability to file new bugs with a C<resolution> was added in Bugzilla B<4.4>.
+
+=head3 Parameters
+
+Some params must be set, or an error will be thrown. These params are marked B<Required>.
+
+Some parameters can have defaults set in Bugzilla, by the administrator. If these parameters have defaults set, you can omit them. These parameters are marked B<Defaulted>.
+
+Clients that want to be able to interact uniformly with multiple Bugzillas should always set both the params marked B<Required> and those marked B<Defaulted>, because some Bugzillas may not have defaults set for B<Defaulted> parameters, and then this method will throw an error if you don't specify them.
+
+The descriptions of the parameters below are what they mean when Bugzilla is being used to track software bugs. They may have other meanings in some installations.
+
+=over 4
+
+=item product (string) B<Required> - The name of the product the bug is being filed against.
+
+I<product> (string) B<Required> - The name of the product the bug is being filed against.
+
+=item component
+
+I<component> (string) B<Required> - The name of a component in the product above.
+
+=item summary
+
+I<summary> (string) B<Required> - A brief description of the bug being filed.
+
+=item version
+
+I<version> (string) B<Required> - A version of the product above; the version the bug was found in.
+
+=item description
+
+I<description> (string) B<Defaulted> - The initial description for this bug. Some Bugzilla installations require this to not be blank.
+
+=item op_sys
+
+I<op_sys> (string) B<Defaulted> - The operating system the bug was discovered on.
+
+=item platform
+
+I<platform> (string) B<Defaulted> - What type of hardware the bug was experienced on.
+
+=item priority
+
+I<priority> (string) B<Defaulted> - What order the bug will be fixed in by the developer, compared to the developer's other bugs.
+
+=item severity
+
+I<severity> (string) B<Defaulted> - How severe the bug is.
+
+=item alias
+
+I<alias> (string) - A brief alias for the bug that can be used instead of a bug number when accessing this bug. Must be unique in all of this Bugzilla.
+
+=item assigned_to
+
+I<assigned_to> (username) - A user to assign this bug to, if you don't want it to be assigned to the component owner.
+
+=item cc
+
+I<cc> (array) - An array of usernames to CC on this bug.
+
+=item comment_is_private
+
+I<comment_is_private> (boolean) - If set to true, the description is private, otherwise it is assumed to be public.
+
+=item groups
+
+I<groups> (array) - An array (ref) of group names to put this bug into. You can see valid group names on the I<Permissions tab> of the I<Preferences screen>, or, if you are an administrator, in the I<Groups control panel>. If you don't specify this argument, then the bug will be added into all the groups that are set as being "Default" for this product. (If you want to avoid that, you should specify C<groups> as an empty array.)
+
+=item qa_contact
+
+I<qa_contact> (username) - If this installation has QA Contacts enabled, you can set the QA Contact here if you don't want to use the component's default QA Contact.
+
+=item status
+
+I<status> (string) - The status that this bug should start out as. Note that only certain statuses can be set on bug creation.
+
+=item resolution
+
+I<resolution> (string) - If you are filing a closed bug, then you will have to specify a resolution. You cannot currently specify a resolution of C<DUPLICATE> for new bugs, though. That must be done with L</update>.
+
+=item target_milestone
+
+I<target_milestone> (string) - A valid target milestone for this product.
+
+=back
+
+B<Note:> In addition to the above parameters, if your installation has any custom fields, you can set them just by passing in the name of the field and its value as a string.
+
+=head3 Returns
+
+A hash with one element, C<id>. This is the id of the newly-filed bug.
+
+=head3 Errors
+
+=over 4
+
+=item 51 - Invalid Object
+
+You specified a field value that is invalid. The error message will have more details.
+
+=item 103 - Invalid Alias
+
+The alias you specified is invalid for some reason. See the error message for more details.
+
+=item 104 - Invalid Field
+
+One of the drop-down fields has an invalid value, or a value entered in a text field is too long. The error message will have more detail.
+
+=item 105 - Invalid Component
+
+You didn't specify a component.
+
+=item 106 - Invalid Product
+
+Either you didn't specify a product, this product doesn't exist, or you don't have permission to enter bugs in this product.
+
+=item 107 - Invalid Summary
+
+You didn't specify a summary for the bug.
+
+=item 116 - Dependency Loop
+
+You specified values in the blocks or depends_on fields that would cause a circular dependency between bugs.
+
+=item 120 - Group Restriction Denied
+
+You tried to restrict the bug to a group which does not exist, or which you cannot use with this product.
+
+=item 504 - Invalid User
+
+Either the QA Contact, Assignee, or CC lists have some invalid user in them. The error message will have more details.
+
+=back
 
 =head2 update
 
@@ -866,7 +1019,388 @@ Allows you to update the fields of a bug.
 
 (Your Bugzilla server may automatically sends emails out about the changes)
 
-FIXME more details needed
+=head3 History
+
+Added in Bugzilla B<4.0>.
+
+=head3 Parameters
+
+=over 4
+
+=item ids
+
+I<ids> (Array of C<int>s or C<string>s) -  The ids or aliases of the bugs that you want to modify.
+
+B<Note:> All following fields specify the values you want to set on the bugs you are updating.
+
+=item alias
+
+I<alias> (string) - The alias of the bug. You can only set this if you are modifying a single bug. If there is more than one bug specified in C<ids>, passing in a value for C<alias> will cause an error to be thrown.
+
+=item assigned_to
+
+I<assigned_to> (string) -  The full login name of the user this bug is assigned to.
+
+=item blocks
+
+I<blocks> (hash) -  These specify the bugs that this bug blocks. To set these, you should pass a hash as the value. The hash may contain the following fields:
+
+=over 4
+
+=item add
+
+I<add> (Array of C<int>s) - Bug ids to add to this field.
+
+=item remove
+
+I<remove> (Array of C<int>s) -  Bug ids to remove from this field. If the bug ids are not already in the field, they will be ignored.
+
+=item set
+
+I<set> (Array of C<int>s) - An exact set of bug ids to set this field to, overriding the current value. If you specify C<set>, then C<add> and C<remove> will be ignored.
+
+=back
+
+=item depends_on
+
+I<depends_on> (hash) -  These specify the bugs that this depends on. To set these, you should pass a hash as the value. The hash may contain the following fields:
+
+=over 4
+
+=item add
+
+I<add> (Array of C<int>s) - Bug ids to add to this field.
+
+=item remove
+
+I<remove> (Array of C<int>s) -  Bug ids to remove from this field. If the bug ids are not already in the field, they will be ignored.
+
+=item set
+
+I<set> (Array of C<int>s) - An exact set of bug ids to set this field to, overriding the current value. If you specify C<set>, then C<add> and C<remove> will be ignored.
+
+=back
+
+=item cc
+
+I<cc> (hash) -  The users on the cc list. To modify this field, pass a hash, which may have the following fields:
+
+=over 4
+
+=item add
+
+I<add> (Array of C<string>s) - User names to add to the CC list. They must be full user names, and an error will be thrown if you pass in an invalid user name.
+
+=item remove
+
+I<remove> (Array of C<string>s) - User names to remove from the CC list. They must be full user names, and an error will be thrown if you pass in an invalid user name.
+
+=back
+
+=item is_cc_accessible
+
+I<is_cc_accessible> (boolean) -  Whether or not users in the CC list are allowed to access the bug, even if they aren't in a group that can normally access the bug.
+
+=item comment
+
+I<comment> (hash) -  A comment on the change. The hash may contain the following fields:
+
+=over 4
+
+=item body
+
+I<body> (string) -  The actual text of the comment. B<Note:> For compatibility with the parameters to L</add_comment>, you can also call this field C<comment>, if you wish.
+
+=item is_private
+
+I<is_private> (boolean) - Whether the comment is private or not. If you try to make a comment private and you don't have the permission to, an error will be thrown.
+
+=back
+
+=item comment_is_private
+
+I<comment_is_private> (hash) - This is how you update the privacy of comments that are already on a bug. This is a hash, where the keys are the C<int> id of comments (not their count on a bug, like #1, #2, #3, but their globally-unique id, as returned by L</comments>) and the value is a C<boolean> which specifies whether that comment should become private (C<true>) or public (C<false>).
+
+The comment ids must be valid for the bug being updated. Thus, it is not practical to use this while updating multiple bugs at once, as a single comment id will never be valid on multiple bugs.
+
+=item component
+I<component> (string) - The Component the bug is in.
+
+=item deadline
+
+I<deadline> (string) -  The Deadline field--a date specifying when the bug must be completed by, in the format C<YYYY-MM-DD>.
+
+=item dupe_of
+
+I<dupe_of> (int) -  The bug that this bug is a duplicate of. If you want to mark a bug as a duplicate, the safest thing to do is to set this value and not set the C<status> or C<resolution> fields. They will automatically be set by Bugzilla to the appropriate values for duplicate bugs.
+
+=item estimated_time
+
+I<estimated_time> (double) - The total estimate of time required to fix the bug, in hours. This is the I<total> estimate, not the amount of time remaining to fix it.
+
+=item groups
+
+I<groups> (hash) -  The groups a bug is in. To modify this field, pass a hash, which may have the following fields:
+
+=over 4
+
+=item add
+
+I<add> (Array of C<string>s) - The names of groups to add. Passing in an invalid group name or a group that you cannot add to this bug will cause an error to be thrown.
+
+=item remove
+
+I<remove> (Array of C<string>s) - The names of groups to remove. Passing in an invalid group name or a group that you cannot remove from this bug will cause an error to be thrown.
+
+=back
+
+=item keywords
+
+I<keywords> (hash) -  Keywords on the bug. To modify this field, pass a hash, which may have the following fields:
+
+=over 4
+
+=item add
+
+I<add> (An array of C<string>s) - The names of keywords to add to the field on the bug. Passing something that isn't a valid keyword name will cause an error to be thrown.
+
+=item remove
+
+I<remove> (An array of C<string>s) - The names of keywords to remove from the field on the bug. Passing something that isn't a valid keyword name will cause an error to be thrown.
+
+=item set
+
+I<set> (An array of C<string>s) - An exact set of keywords to set the field to, on the bug. Passing something that isn't a valid keyword name will cause an error to be thrown. Specifying C<set> overrides C<add> and C<remove>.
+
+=back
+
+=item op_sys
+
+I<op_sys> (string) -  The Operating System ("OS") field on the bug.
+
+=item platform
+
+I<platform> (string) - The Platform or "Hardware" field on the bug.
+
+=item priority
+
+I<priority> (string) -  The Priority field on the bug.
+
+=item product
+
+I<product> (string) - The name of the product that the bug is in. If you change this, you will probably also want to change C<target_milestone>, C<version>, and C<component>, since those have different legal values in every product.
+
+If you cannot change the C<target_milestone> field, it will be reset to the default for the product, when you move a bug to a new product.
+
+You may also wish to add or remove groups, as which groups are valid on a bug depends on the product. Groups that are not valid in the new product will be automatically removed, and groups which are mandatory in the new product will be automaticaly added, but no other automatic group changes will be done.
+
+B<Note:> that users can only move a bug into a product if they would normally have permission to file new bugs in that product.
+
+=item qa_contact
+
+I<qa_contact> (string) - The full login name of the bug's QA Contact.
+
+=item is_creator_accessible
+
+I<is_creator_accessible> (boolean) - Whether or not the bug's reporter is allowed to access the bug, even if he or she isn't in a group that can normally access the bug.
+
+=item remaining_time
+
+I<remaining_time> (double) - How much work time is remaining to fix the bug, in hours. If you set C<work_time> but don't explicitly set C<remaining_time>, then the C<work_time> will be deducted from the bug's C<remaining_time>.
+
+=item reset_assigned_to
+
+I<reset_assigned_to> (boolean) - If true, the C<assigned_to> field will be reset to the default for the component that the bug is in. (If you have set the component at the same time as using this, then the component used will be the new component, not the old one.)
+
+=item reset_qa_contact
+
+I<reset_qa_contact> (boolean) - If true, the C<qa_contact> field will be reset to the default for the component that the bug is in. (If you have set the component at the same time as using this, then the component used will be the new component, not the old one.)
+
+=item resolution
+
+I<resolution> (string) The current resolution. May only be set if you are closing a bug or if you are modifying an already-closed bug. Attempting to set the resolution to I<any> value (even an empty or null string) on an open bug will cause an error to be thrown.
+
+If you change the C<status> field to an open status, the resolution field will automatically be cleared, so you don't have to clear it manually.
+
+=item see_also
+
+I<see_also> (hash) - The See Also field on a bug, specifying URLs to bugs in other bug trackers. To modify this field, pass a hash, which may have the following fields:
+
+=over 4
+
+=item add
+
+I<add> (An array of C<string>s) - URLs to add to the field. Each URL must be a valid URL to a bug-tracker, or an error will be thrown.
+
+=item remove
+
+I<remove> (An array of C<string>s) - URLs to remove from the field. Invalid URLs will be ignored.
+
+=back
+
+=item severity
+
+I<severity> (string) - The Severity field of a bug.
+
+=item status
+
+I<status> (string) - The status you want to change the bug to. Note that if a bug is changing from open to closed, you should also specify a resolution.
+
+=item summary
+
+I<summary> (string) - The Summary field of the bug.
+
+=item target_milestone
+
+I<target_milestone> (string) -  The bug's Target Milestone.
+
+=item url
+
+I<url> (string) - The "URL" field of a bug.
+
+=item version
+
+I<version> (string) -  The bug's Version field.
+
+=item whiteboard
+
+I<whiteboard> (string) - The Status Whiteboard field of a bug.
+
+=item work_time
+
+I<work_time> (double) - The number of hours worked on this bug as part of this change. If you set C<work_time> but don't explicitly set C<remaining_time>, then the C<work_time> will be deducted from the bug's remaining_time.
+
+=back
+
+B<Note:> You can also set the value of any custom field by passing its name as a parameter, and the value to set the field to. For multiple-selection fields, the value should be an array of strings.
+
+=head3 Returns
+
+A C<hash> with a single field, "bugs". This points to an array of hashes with the following fields:
+
+=over 4
+
+=item id
+
+I<id> (int) - The id of the bug that was updated.
+
+=item alias
+
+I<alias> (string) - The alias of the bug that was updated, if this bug has an alias.
+
+=item last_change_time
+
+I<last_change_time> (L<DateTime>) - The exact time that this update was done at, for this bug. If no update was done (that is, no fields had their values changed and no comment was added) then this will instead be the last time the bug was updated.
+
+=item changes
+
+I<changes> (hash) - The changes that were actually done on this bug. The keys are the names of the fields that were changed, and the values are a hash with two keys:
+
+=over 4
+
+=item added
+
+I<added> (string) - The values that were added to this field, possibly a comma-and-space-separated list if multiple values were added.
+
+=item removed
+
+I<removed> (string) - The values that were removed from this field, possibly a comma-and-space-separated list if multiple values were removed.
+
+=back
+
+=back
+
+Here's an example of what a return value might look like:
+
+ {
+   bugs => [
+     {
+       id    => 123,
+       alias => 'foo',
+       last_change_time => '2010-01-01T12:34:56',
+       changes => {
+         status => {
+           removed => 'NEW',
+           added   => 'ASSIGNED'
+         },
+         keywords => {
+           removed => 'bar',
+           added   => 'qux, quo, qui',
+         },
+       },
+     },
+   ],
+ }
+
+B<Note:> Currently, some fields are not tracked in changes: C<comment>, C<comment_is_private>, and C<work_time>. This means that they will not show up in the return value even if they were successfully updated. This may change in a future version of Bugzilla.
+
+=head3 Errors
+
+This function can throw all of the errors that L</get>, L</create>, and L</add_comment> can throw, plus:
+
+=over 4
+
+=item 50 - Empty Field
+
+You tried to set some field to be empty, but that field cannot be empty. The error message will have more details.
+
+=item 52 - Input Not A Number
+
+You tried to set a numeric field to a value that wasn't numeric.
+
+=item 54 - Number Too Large
+
+You tried to set a numeric field to a value larger than that field can accept.
+
+=item 55 - Number Too Small
+
+You tried to set a negative value in a numeric field that does not accept negative values.
+
+=item 56 - Bad Date/Time
+
+You specified an invalid date or time in a date/time field (such as the deadline field or a custom date/time field).
+
+=item 112 - See Also Invalid
+
+You attempted to add an invalid value to the see_also field.
+
+=item 115 - Permission Denied
+
+You don't have permission to change a particular field to a particular value. The error message will have more detail.
+
+=item 116 - Dependency Loop
+
+You specified a value in the blocks or depends_on fields that causes a dependency loop.
+
+=item 117 - Invalid Comment ID
+
+You specified a comment id in comment_is_private that isn't on this bug.
+
+=item 118 - Duplicate Loop
+
+You specified a value for dupe_of that causes an infinite loop of duplicates.
+
+=item 119 - dupe_of Required
+
+You changed the resolution to DUPLICATE but did not specify a value for the dupe_of field.
+
+=item 120 - Group Add/Remove Denied
+
+You tried to add or remove a group that you don't have permission to modify for this bug, or you tried to add a group that isn't valid in this product.
+
+=item 121 - Resolution Required
+
+You tried to set the status field to a closed status, but you didn't specify a resolution.
+
+=item 122 - Resolution On Open Status
+
+This bug has an open status, but you specified a value for the resolution field.
+
+=item 123 - Invalid Status Transition
+
+You tried to change from one status to another, but the status workflow rules don't allow that change.
+
+=back
 
 =head2 update_see_also
 
@@ -905,7 +1439,7 @@ If you specify a URL that is not in the I<See Also> field of a particular bug, i
 
 =back
 
-NOTE: If you specify the same URL in both L</add> and L</remove>, it will be added. (That is, L</add> overrides L</remove>.)
+B<Note:> If you specify the same URL in both L</add> and L</remove>, it will be added. (That is, L</add> overrides L</remove>.)
 
 =head3 Returns
 
@@ -975,6 +1509,12 @@ Before Bugzilla 3.6, error 115 had a generic error code of 32000.
 
 Adds or removes tags on bugs.
 
+Unlike Keywords which are global and visible by all users, Tags are personal and can only be viewed and edited by their author. Editing them won't send any notification to other users. Use them to tag and keep track of bugs.
+
+Bugzilla will lower case the text of the tags. This doesn't seem to be documented.
+
+B<Reminder:> to retrieve these tags, specify C<_extra> or the field name C<tags> in L</include_fields> when searching etc.
+
 =head3 History
 
 This is marked as B<UNSTABLE> in Bugzilla 4.4
@@ -1188,7 +1728,9 @@ these are yet to be specifically implemented.
 
 L<BZ::Client>, L<BZ::Client::Bug::Attachment>, L<BZ::Client::Bug::Comment>
 
-L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bug.html>
+L<BZ::Client::API>,
+L<Bugzilla WebService 4.4 API|https://www.bugzilla.org/docs/4.4/en/html/api/Bugzilla/WebService/Bug.html>,
+L<Bugzilla WebService 5.0 API|https://www.bugzilla.org/docs/5.0/en/html/integrating/api/Bugzilla/WebService/Bug.html>
 
 =head1 AUTHORS
 
@@ -1206,7 +1748,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dean Hamstad.
+This software is copyright (c) 2017 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
