@@ -6,9 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bug::Comment;
-$BZ::Client::Bug::Comment::VERSION = '4.4_001'; # TRIAL
+$BZ::Client::Bug::Comment::VERSION = '4.4001_001'; # TRIAL
 
-$BZ::Client::Bug::Comment::VERSION = '4.4001';use parent qw( BZ::Client::API );
+$BZ::Client::Bug::Comment::VERSION = '4.4001001';use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bug.html
 # These are in order as per the above
@@ -17,6 +17,9 @@ $BZ::Client::Bug::Comment::VERSION = '4.4001';use parent qw( BZ::Client::API );
 
 sub get {
     my($class, $client, $params) = @_;
+    unless (ref $params) {
+        $params = { id => $params };
+    }
     $client->log('debug', __PACKAGE__ . "::get: Asking for $params");
     my $result = $class->api_call($client, 'Bug.comments', $params);
 
@@ -143,7 +146,7 @@ BZ::Client::Bug::Comment - Client side representation of an Comment on a Bug in
 
 =head1 VERSION
 
-version 4.4_001
+version 4.4001_001
 
 =head1 SYNOPSIS
 
@@ -162,6 +165,9 @@ This section lists the class methods, which are available in this module.
 
 =head2 get
 
+  my $comments = BZ::Client::Bug::Comment->get( $client, 1234 );
+  my $comments = BZ::Client::Bug::Comment->get( $client, { ids => \@list, commend_ids => \@list } );
+
 This allows you to get data about comments, given a list of bugs and/or comment ids.
 
 Actual Bugzilla API method is "comments".
@@ -172,6 +178,8 @@ Added in Bugzilla 3.4
 
 =head3 Parameters
 
+A single scalar is considered a search for L</ids>, otherwise a hash reference must be provided.
+
 Note: At least one of L</ids> or L</comment_ids> is required.
 
 In addition to the parameters below, this method also accepts the standard L<BZ::Client::Bug/include_fields> and L<BZ::Client::Bug/exclude_fields> arguments.
@@ -194,23 +202,44 @@ I<new_since> (L<DateTime>) - If specified, the method will only return comments
 
 =head3 Returns
 
-A hash containing two items is returned:
+A hash reference containing two items is returned. e.g.
+
+ {
+
+     bugs => {
+         123 => \@comments,
+         456 => \@comments,
+     },
+
+     comments => {
+         789 => $comment,
+     },
+
+ }
+
+The Bugzilla WebService documentation doesnt state what order the comments will be in, however they seem to be returned [ oldest, newest ]. If this order is important to you, then you should sort them just to be sure.
+
+More details on the above example:
 
 =over 4
 
 =item bugs
 
-This is used for bugs specified in L</ids>. This is a hash, where the keys are the numeric IDs of the bugs, and the value is a hash with a single key, I<comments>, which is an array of comments. (The format of comments is described below)
+This is used for bugs specified in L</ids> parameter.
+
+This is a hash, wherein the keys are the numeric IDs of the bugs, and the corresponding value is an array ref of comment objects.
 
 Note that any individual bug will only be returned once, so if you specify an ID multiple times in ID's, it will still only be returned once.
 
 =item comments
 
-Each individual comment requested in L</comment_ids> is returned here, in a hash where the numeric comment ID is the key, and the value is the comment. (The format of comments is described below)
+Each individual comment requested in L</comment_ids> is returned here.
+
+This is a hash wherein the keys are the numeric comment ID, and the corresponding value is the comment object.
 
 =back
 
-A "comment" as described above is an object instance of this package.
+A "comment" as described above is an object instance of this package i.e. L<BZ::Client::Bug::Comment>.
 
 =head3 Errors
 
@@ -475,7 +504,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dean Hamstad.
+This software is copyright (c) 2017 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
