@@ -6,9 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bugzilla;
-$BZ::Client::Bugzilla::VERSION = '4.4_001'; # TRIAL
+$BZ::Client::Bugzilla::VERSION = '4.4001_001'; # TRIAL
 
-$BZ::Client::Bugzilla::VERSION = '4.4001';
+$BZ::Client::Bugzilla::VERSION = '4.4001001';
 use parent qw( BZ::Client::API );
 
 ## functions
@@ -97,7 +97,7 @@ BZ::Client::Bugzilla - Information about the Bugzilla server, i.e. the Bugzilla:
 
 =head1 VERSION
 
-version 4.4_001
+version 4.4001_001
 
 =head1 SYNOPSIS
 
@@ -270,6 +270,10 @@ Also, Bugzilla has depreceated but not yet removed this API call
 
 Returns the Bugzilla servers version.
 
+=head1 EXCEPTION HANDLING
+
+See L<BZ::Client::Exception>
+
 =head1 SEE ALSO
 
 L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bugzilla.html>
@@ -290,7 +294,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dean Hamstad.
+This software is copyright (c) 2017 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
