@@ -6,9 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Classification;
-$BZ::Client::Classification::VERSION = '4.4_001'; # TRIAL
+$BZ::Client::Classification::VERSION = '4.4001_001'; # TRIAL
 
-$BZ::Client::Classification::VERSION = '4.4001';
+$BZ::Client::Classification::VERSION = '4.4001001';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Classificaton.html
@@ -36,7 +36,7 @@ BZ::Client::Classification - Client side representation of Classifications in Bu
 
 =head1 VERSION
 
-version 4.4_001
+version 4.4001_001
 
 =head1 SYNOPSIS
 
@@ -141,6 +141,10 @@ Classification is not enabled on this installation.
 
 =back
 
+=head1 EXCEPTION HANDLING
+
+See L<BZ::Client::Exception>
+
 =head1 SEE ALSO
 
 L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Classification.html>
@@ -161,7 +165,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dean Hamstad.
+This software is copyright (c) 2017 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
