@@ -6,9 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::User;
-$BZ::Client::User::VERSION = '4.4_001'; # TRIAL
+$BZ::Client::User::VERSION = '4.4001_001'; # TRIAL
 
-$BZ::Client::User::VERSION = '4.4001';
+$BZ::Client::User::VERSION = '4.4001001';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/User.html
@@ -83,7 +83,7 @@ BZ::Client::User - Creates and edits user accounts in Bugzilla
 
 =head1 VERSION
 
-version 4.4_001
+version 4.4001_001
 
 =head1 SYNOPSIS
 
@@ -479,6 +479,10 @@ Logged-in users are not authorized to edit other users.
 
 =back
 
+=head1 EXCEPTION HANDLING
+
+See L<BZ::Client::Exception>
+
 =head1 SEE ALSO
 
 L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/User.html>
@@ -499,7 +503,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dean Hamstad.
+This software is copyright (c) 2017 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
